@@ -6,6 +6,7 @@ from django.core.files.storage import get_storage_class
 from django.db import models
 from django.db.models.signals import post_delete
 from django.template.defaultfilters import slugify
+from django.utils.timezone import now, utc
 from django.utils.translation import ugettext_lazy as _
 
 from dirtyfields import DirtyFieldsMixin
@@ -313,7 +314,7 @@ def make_model_from_api(api_record, videoclass=ViddlerVideo):
         audio_only=api_record.get('audio_only', False),
         view_count=api_record['view_count'] and int(api_record['view_count']) or 0,
         impression_count=api_record['impression_count'] and int(api_record['impression_count']) or 0,
-        upload_time=datetime.datetime.utcfromtimestamp(int(api_record['upload_time'])),
+        upload_time=datetime.datetime.utcfromtimestamp(int(api_record['upload_time']), tzinfo=utc),
         favorite=api_record['favorite'],
         comment_count=api_record['comment_count'],
         thumbnails_count=api_record['thumbnails_count'],
@@ -330,12 +331,12 @@ def make_model_from_api(api_record, videoclass=ViddlerVideo):
         data_dict['slug'] = api_record['slug']
     made_public = api_record['made_public_time'] and int(api_record['made_public_time'])
     if made_public:
-        data_dict['made_public_time'] = datetime.datetime.utcfromtimestamp(made_public)
+        data_dict['made_public_time'] = datetime.datetime.utcfromtimestamp(made_public, tzinfo=utc)
     tags = []
     for tag in api_record.get('tags', []):
         tags.append(tag['text'])
     data_dict['tags'] = ",".join(tags)
-    data_dict['last_synced'] = datetime.datetime.now()
+    data_dict['last_synced'] = now()
 
     try:
         video = videoclass.objects.get(viddler_id=api_record['id'])
